Enum ultron::editor::Msg [−][src]
pub enum Msg {
Show 19 variants
TextareaMounted(Node),
EditorMounted(Node),
Keydown(KeyboardEvent),
TextareaKeydown(KeyboardEvent),
MoveCursor(usize, usize),
MoveCursorToLine(usize),
StartSelection(usize, usize),
EndSelection(usize, usize),
StopSelection,
ToSelection(usize, usize),
Paste(String),
CopiedSelected,
Mouseup(i32, i32),
Mousedown(i32, i32),
Mousemove(i32, i32),
SetMeasurement(Measurements),
Scrolled((i32, i32)),
WindowScrolled((i32, i32)),
TextareaInput(String),
}Variants
TextareaMounted(Node)Tuple Fields of TextareaMounted
0: NodeEditorMounted(Node)Tuple Fields of EditorMounted
0: NodeKeydown(KeyboardEvent)Tuple Fields of Keydown
TextareaKeydown(KeyboardEvent)Tuple Fields of TextareaKeydown
MoveCursorToLine(usize)Tuple Fields of MoveCursorToLine
0: usizePaste(String)Tuple Fields of Paste
0: StringTextareaInput(String)Tuple Fields of TextareaInput
0: StringTrait Implementations
Update the model of this component and return follow up and/or effects that will be executed on the next update loop Read more